==> peruse_1.2+dfsg+20181001.orig.tar.xz: peruse-1.2+20181001/src/contentlist/ContentListerBase.cpp <==
/*
 * Copyright (C) 2015 Dan Leinir Turthra Jensen <admin@leinir.dk>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "ContentListerBase.h"

#include <QVariantMap>
#include <QFileInfo>
#include <QDateTime>

#include <KFileMetaData/UserMetaData>

ContentListerBase::ContentListerBase(QObject* parent)
    : QObject(parent)
{
}

ContentListerBase::~ContentListerBase()
{
}


void ContentListerBase::startSearch(const QList<ContentQuery*>& queries)
{
    Q_UNUSED(queries);
}

QVariantMap ContentListerBase::metaDataForFile(const QString& file)
{
    QVariantMap metadata;

    //TODO: This should include the same information for both the Baloo and
    //File searchers. Unfortunately, currently KFileMetaData does not seem able
    //to provide this. So this needs changes at a lower level.

    QFileInfo info(file);
    metadata["lastModified"] = info.lastModified();
    metadata["created"] = info.created();
    metadata["lastRead"] = info.lastRead();

    KFileMetaData::UserMetaData data(file);
    if (data.hasAttribute("peruse.currentPage")) {
        int currentPage = data.attribute("peruse.currentPage").toInt();
        metadata["currentPage"] = QVariant::fromValue<int>(currentPage);
    }
    if (data.hasAttribute("peruse.totalPages")) {
        int totalPages = data.attribute("peruse.totalPages").toInt();
        metadata["totalPages"] = QVariant::fromValue<int>(totalPages);
    }
    if (!data.tags().isEmpty()) {
        metadata["tags"] = QVariant::fromValue<QStringList>(data.tags());
    }
    if (!data.userComment().isEmpty()) {
        metadata["comment"] = QVariant::fromValue<QString>(data.userComment());
    }
    metadata["rating"] = QVariant::fromValue<int>(data.rating());

    return metadata;
}

==> peruse_1.80+dfsg.orig.tar.xz: peruse-1.80/src/contentlist/ContentListerBase.cpp <==
/*
 * Copyright (C) 2015 Dan Leinir Turthra Jensen <admin@leinir.dk>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "ContentListerBase.h"

#include <QVariantMap>
#include <QFileInfo>
#include <QDateTime>

#include <KFileMetaData/UserMetaData>

ContentListerBase::ContentListerBase(QObject* parent)
    : QObject(parent)
{
}

ContentListerBase::~ContentListerBase()
{
}


void ContentListerBase::startSearch(const QList<ContentQuery*>& queries)
{
    Q_UNUSED(queries);
}

QVariantMap ContentListerBase::metaDataForFile(const QString& file)
{
    QVariantMap metadata;

    //TODO: This should include the same information for both the Baloo and
    //File searchers. Unfortunately, currently KFileMetaData does not seem able
    //to provide this. So this needs changes at a lower level.

    QFileInfo info(file);
    metadata["lastModified"] = info.lastModified();
    metadata["created"] = info.birthTime();
    metadata["lastRead"] = info.lastRead();

    KFileMetaData::UserMetaData data(file);
    if (data.hasAttribute("peruse.currentPage")) {
        int currentPage = data.attribute("peruse.currentPage").toInt();
        metadata["currentPage"] = QVariant::fromValue<int>(currentPage);
    }
    if (data.hasAttribute("peruse.totalPages")) {
        int totalPages = data.attribute("peruse.totalPages").toInt();
        metadata["totalPages"] = QVariant::fromValue<int>(totalPages);
    }
    if (!data.tags().isEmpty()) {
        metadata["tags"] = QVariant::fromValue<QStringList>(data.tags());
    }
    if (!data.userComment().isEmpty()) {
        metadata["comment"] = QVariant::fromValue<QString>(data.userComment());
    }
    metadata["rating"] = QVariant::fromValue<int>(data.rating());

    return metadata;
}
